function [flt_pr,S]=kimnelson(p00,p11,LS0,LS1,PHIS0,PHIS1,S_F_S0,S_F_S1,RHOS0,RHOS1,SIGMA_vS0,SIGMA_vS1,X_temp,FY_temp,FY_lag)

%This program is based on Kim and Nelson's Gauss Code

%== Inputs ==
% p00,p11: two state transition probability
% LS0, LS1: state dependent factor loading coefficients
% PHIS0,PHIS1: state dependent factor VAR coefficients
% S_F_S0, S_F_S1: state dependent factro VAR error variance matrix
% RHO_S0, RHO_S1: state dependent error VAR coefficients
% SIGMA_vS0,SIGMA_vS1: state dependent error VAR error variance matrix

%== Outputs ==
% S: draw of states, in 0s and 1s
% flt_pr: filtered probability (Pr(St=0);Pr(St)=1), 2xT

%===Preliminaries

Tstar = size(FY_lag,1); 
N=size(X_temp,2);
flt_pr=zeros(2,Tstar); 

pr_tr=[p00,1-p11;1-p00,p11]; 

A=[eye(2)-pr_tr;ones(1,2)];
EN=[0;0;1];
prob_T=inv(A'*A)*A'*EN; 

%================= Compute filtered probability ================================

fltpr0=prob_T; 

pr_TRF0=pr_tr(:); 
pr_trf=[pr_TRF0;pr_TRF0]; 
probb=[prob_T prob_T]';
prob_T=probb(:).*pr_TRF0; 
fltpr1=prob_T(1:2)+prob_T(3:4); 

probb=[prob_T prob_T]'; 
prob__=probb(:); 

for t=3:Tstar
    prob_dd=pr_trf.*prob__; 
        
    Xmean000=FY_lag(t,:)*PHIS0*LS0'+[(X_temp(t-1,:)-FY_temp(t-1,:)*LS0'),(X_temp(t-2,:)-FY_temp(t-2,:)*LS0')]*RHOS0; %St=0,St-1=0,St-2=0
    Xmean001=FY_lag(t,:)*PHIS1*LS1'+[(X_temp(t-1,:)-FY_temp(t-1,:)*LS0'),(X_temp(t-2,:)-FY_temp(t-2,:)*LS0')]*RHOS1; %St=1,St-1=0,St-2=0
    Xmean010=FY_lag(t,:)*PHIS0*LS0'+[(X_temp(t-1,:)-FY_temp(t-1,:)*LS1'),(X_temp(t-2,:)-FY_temp(t-2,:)*LS0')]*RHOS0; %St=0,St-1=1,St-2=0
    Xmean011=FY_lag(t,:)*PHIS1*LS1'+[(X_temp(t-1,:)-FY_temp(t-1,:)*LS1'),(X_temp(t-2,:)-FY_temp(t-2,:)*LS0')]*RHOS1; %St=1,St-1=1,St-2=0
    Xmean100=FY_lag(t,:)*PHIS0*LS0'+[(X_temp(t-1,:)-FY_temp(t-1,:)*LS0'),(X_temp(t-2,:)-FY_temp(t-2,:)*LS1')]*RHOS0; %St=0,St-1=0,St-2=1
    Xmean101=FY_lag(t,:)*PHIS1*LS1'+[(X_temp(t-1,:)-FY_temp(t-1,:)*LS0'),(X_temp(t-2,:)-FY_temp(t-2,:)*LS1')]*RHOS1; %St=1,St-1=0,St-2=1
    Xmean110=FY_lag(t,:)*PHIS0*LS0'+[(X_temp(t-1,:)-FY_temp(t-1,:)*LS1'),(X_temp(t-2,:)-FY_temp(t-2,:)*LS1')]*RHOS0; %St=0,St-1=1,St-2=1
    Xmean111=FY_lag(t,:)*PHIS1*LS1'+[(X_temp(t-1,:)-FY_temp(t-1,:)*LS1'),(X_temp(t-2,:)-FY_temp(t-2,:)*LS1')]*RHOS1; %St=1,St-1=1,St-2=1
    
    %== Variance of Xt|t-1 = 
       
    XVar0=LS0*S_F_S0*LS0'+SIGMA_vS0; 
    XVar1=LS1*S_F_S1*LS1'+SIGMA_vS1; 
    XVardet0=det(XVar0);
    XVardet1=det(XVar1);
    XVardet=[XVardet0;XVardet1;XVardet0;XVardet1;XVardet0;XVardet1;XVardet0;XVardet1];
    
    Xtstat000=(X_temp(t,:)-Xmean000)/(XVar0)*(X_temp(t,:)-Xmean000)';
    Xtstat001=(X_temp(t,:)-Xmean001)/(XVar1)*(X_temp(t,:)-Xmean001)';
    Xtstat010=(X_temp(t,:)-Xmean010)/(XVar0)*(X_temp(t,:)-Xmean010)';
    Xtstat011=(X_temp(t,:)-Xmean011)/(XVar1)*(X_temp(t,:)-Xmean011)';
    Xtstat100=(X_temp(t,:)-Xmean100)/(XVar0)*(X_temp(t,:)-Xmean100)';
    Xtstat101=(X_temp(t,:)-Xmean101)/(XVar1)*(X_temp(t,:)-Xmean101)';
    Xtstat110=(X_temp(t,:)-Xmean110)/(XVar0)*(X_temp(t,:)-Xmean110)';
    Xtstat111=(X_temp(t,:)-Xmean111)/(XVar1)*(X_temp(t,:)-Xmean111)';
    
    Xtstat=[Xtstat000;Xtstat001;Xtstat010;Xtstat011;Xtstat100;Xtstat101;Xtstat110;Xtstat111]; 
    
    pr_vl=(1./sqrt(2^N.*pi.*XVardet)).*exp(-0.5.*Xtstat).*prob_dd;
    
    pr_val=sum(pr_vl);
    pro_=pr_vl./pr_val;
    
    prob_T=pro_(1:4,1)+pro_(5:8,1); 
    
    flt_pr(:,t)=prob_T(1:2)+prob_T(3:4); 
    probb=[prob_T,prob_T]';
    prob__= probb(:); 
    
end   

flt_pr(:,1)=fltpr0;
flt_pr(:,2)=fltpr1;

%===========Generate S1:T Based on Carter Kohn (1994) =================================

S=zeros(Tstar,1);

S(Tstar,1)= bingen(1,0,1);

j=Tstar-1;
while j>0
 if S(j+1,1)==0;
     p0=p00*flt_pr(1,j);
     p1=(1-p11)*flt_pr(2,j);
 elseif S(j+1,1)==1;
     p0=(1-p00)*flt_pr(1,j);
     p1=p11*flt_pr(2,j);
 end
 S(j,1)=bingen(p0,p1,1);
 j=j-1;
end

end

