% Uniqueness of Solution & Sensitiveness to Parameter Choice

% 10/09/2011 by Fang Zhang

clear all;
close all;

L=5;
N=1000;

m=(L-1)*2;
N_K=15; 

% Parameter Choice
rhoA=0.85; 
rhoS=0.01; 

sigmaA= [2;3.5;5];
sigmaS = [5;5.80;9];
phi= 9.6;

kappa=1:4/N_K:4.96;
size(kappa);

N_sigma=3;

a=zeros(N_sigma,L); 
b=zeros(N_sigma,L); 

Ashock = normrnd(0,1,L,N);
Sshock = normrnd(0,1,L,N);
Anoise = normrnd(0,1,L,N);
Snoise = normrnd(0,1,L,N);


for l=1:L
    for i=1:N_sigma
        a(i,l)=rhoA^(l-1)*sigmaA(i);
        b(i,l)=rhoS^(l-1)*sigmaS(i);
    end
end

p_diamA=zeros(N_sigma,N);
p_diamS=zeros(N_sigma,N);
t=L+1;
for n=1:N
    for i=1:N_sigma
    p_diamA(i,n)= a(i,:)*flipud(squeeze(Ashock(t-L:t-1,n)));
    p_diamS(i,n)= b(i,:)*flipud(squeeze(Sshock(t-L:t-1,n)));
    end
end

options1 = optimset('LargeScale','Off','Display','iter','MaxIter',20,'TolFun',0.01,'TolX',0.01);
options2 = optimset('LargeScale','Off','Display','iter','MaxIter',20,'TolFun',0.01,'TolX',0.01);

c=zeros(N_K,L,N_sigma);
d=zeros(N_K,L,N_sigma);
f=zeros(N_K,L,N_sigma);
g=zeros(N_K,L,N_sigma);

 for i=1:N_sigma
     for k=1:N_K
        [c(k,:,i),d(k,:,i),f(k,:,i),g(k,:,i),kA,kS]=alloc(kappa(k),a(i,:)',b(i,:)',L,m,options1,options2); 
     end
 end
 
 pA=zeros(N_sigma,N,N_K); pS=zeros(N_sigma,N,N_K);
 for n=1:N
    for i=1:N_sigma
        for k=1:N_K
            pA(i,n,k)=c(k,:,i)*flipud(squeeze(Ashock(t-L:t-1,n)))+d(k,:,i)*flipud(squeeze(Anoise(t-L:t-1,n)));
            pS(i,n,k)=f(k,:,i)*flipud(squeeze(Sshock(t-L:t-1,n)))+g(k,:,i)*flipud(squeeze(Snoise(t-L:t-1,n)));
        end
    end
 end
 
 loss=zeros(N_sigma,N_K,N);lossA=zeros(N_sigma,N_K,N);lossS=zeros(N_sigma,N_K,N);
 for i=1:N_sigma
     for k=1:N_K
         for n=1:N
         loss(i,k,n)=(pA(i,n,k)-p_diamA(i,n)).^2+(pS(i,n,k)-p_diamS(i,n)).^2;
         lossA(i,k,n)=(pA(i,n,k)-p_diamA(i,n)).^2;
         lossS(i,k,n)=(pS(i,n,k)-p_diamS(i,n)).^2;
         end
     end
 end
 loss=mean(loss,3);lossA=mean(lossA,3);lossS=mean(lossS,3);
 
 mb=-(loss(:,2:end)-loss(:,1:end-1))./(4/N_K);
 figure() 
 
 subplot(121)
 plot1=plot(kappa(2:end),mb(1,:),kappa(2:end),mb(2,:),kappa(2:end),mb(3,:),kappa(2:end),phi*ones(1,N_K-1)); % plot optimal kappa for different sigmaA
 legend('Vol_A=2.0, Vol_S=5.0','Vol_A=3.5, Vol_S=5.8','Vol_A=5.0, Vol_S=9.0')
 
 set(plot1(1),'Marker','^','LineWidth',1);
set(plot1(2),'Marker','*','LineWidth',1);
set(plot1(3),'Marker','pentagram','LineWidth',1);
set(plot1(4),'LineStyle','--','LineWidth',1,'color',[0,0,0]);
xlim=[0.5,5];
xlabel('K');
ylabel('Marginal Benefit / Cost');
title('Volatility and Optimal Information Capacity');

L=5;
N=1000;

m=(L-1)*2;
N_K=15; 

rhoA=[0.6;0.85;0.9] 
rhoS=[0;0.01;0.1] 
sigmaA= 3.50;
sigmaS = 5.8;
phi= 9.6;

kappa=1:4/N_K:4.96;
size(kappa);

N_rho=3;

a=zeros(N_rho,L); 
b=zeros(N_rho,L); 

Ashock = normrnd(0,1,L,N);
Sshock = normrnd(0,1,L,N);
Anoise = normrnd(0,1,L,N);
Snoise = normrnd(0,1,L,N);


for l=1:L
    for i=1:N_rho
        a(i,l)=rhoA(i)^(l-1)*sigmaA;
        b(i,l)=rhoS(i)^(l-1)*sigmaS;
    end
end

p_diamA=zeros(N_rho,N);
p_diamS=zeros(N_rho,N);
t=L+1;
for n=1:N
    for i=1:N_rho
    p_diamA(i,n)= a(i,:)*flipud(squeeze(Ashock(t-L:t-1,n)));
    p_diamS(i,n)= b(i,:)*flipud(squeeze(Sshock(t-L:t-1,n)));
    end
end

options1 = optimset('LargeScale','Off','Display','iter','MaxIter',20,'TolFun',0.01,'TolX',0.01);
options2 = optimset('LargeScale','Off','Display','iter','MaxIter',20,'TolFun',0.01,'TolX',0.01);

c=zeros(N_K,L,N_rho);
d=zeros(N_K,L,N_rho);
f=zeros(N_K,L,N_rho);
g=zeros(N_K,L,N_rho);

 for i=1:N_rho
     for k=1:N_K
        [c(k,:,i),d(k,:,i),f(k,:,i),g(k,:,i),kA,kS]=alloc(kappa(k),a(i,:)',b(i,:)',L,m,options1,options2);
        
     end
 end
 
 pA=zeros(N_rho,N,N_K);
 pS=zeros(N_rho,N,N_K);
 for n=1:N
    for i=1:N_rho
        for k=1:N_K
            pA(i,n,k)=c(k,:,i)*flipud(squeeze(Ashock(t-L:t-1,n)))+d(k,:,i)*flipud(squeeze(Anoise(t-L:t-1,n)));
            pS(i,n,k)=f(k,:,i)*flipud(squeeze(Sshock(t-L:t-1,n)))+g(k,:,i)*flipud(squeeze(Snoise(t-L:t-1,n)));
        end
    end
 end
 
loss=zeros(N_rho,N_K,N);
lossA=zeros(N_rho,N_K,N);
lossS=zeros(N_rho,N_K,N);
 for i=1:N_rho
     for k=1:N_K
         for n=1:N
         loss(i,k,n)=(pA(i,n,k)-p_diamA(i,n)).^2+(pS(i,n,k)-p_diamS(i,n)).^2;
         lossA(i,k,n)=(pA(i,n,k)-p_diamA(i,n)).^2;
         lossS(i,k,n)=(pS(i,n,k)-p_diamS(i,n)).^2;
         end
     end
 end
 loss=mean(loss,3);
 lossA=mean(lossA,3);
 lossS=mean(lossS,3);
 
 mb=-(loss(:,2:end)-loss(:,1:end-1))./(4/N_K);
 

subplot(122)
 plot2=plot(kappa(2:end),mb(1,:),kappa(2:end),mb(2,:),kappa(2:end),mb(3,:),kappa(2:end),phi*ones(1,N_K-1)); % plot optimal kappa for different sigmaA
 legend('Rho_A=0.75, Rho_S=0','Rho_A=0.85, Rho_S=0.01','Rho_A=0.9, Rho_S=0.15')
 
set(plot2(1),'Marker','^','LineWidth',1);
set(plot2(2),'Marker','*','LineWidth',1);
set(plot2(3),'Marker','pentagram','LineWidth',1);
set(plot2(4),'LineStyle','--','LineWidth',1,'color',[0,0,0]);
xlim=[0.5,5];
xlabel('K');
ylabel('Marginal Benefit / Cost');
title('Persistence and Optimal Information Capacity');

