clear all; close all;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Parameters and Preliminaries
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

phi=9.6; 
L=5; 
k=4;

T1=2*L+k*4*L+L;

N=100; 
I=200; 
m = (L-1)*2; 

lambda1 = 0.857; 
lambda2 = 0.916; 

recindex=[2*L+k*L+1:2*L+2*k*L 2*L+3*k*L+1:2*L+4*k*L]';
expindex=[1:2*L+k*L 2*L+2*k*L+1:2*L+3*k*L 2*L+4*k*L+1:T1]';

sigma_LA = 1;  
sigma_HA = 3.5*sigma_LA; 
sigma_LS = 5.9*sigma_LA;
sigma_HS = 5.8*sigma_LA;  
sigmaA(expindex)= sigma_LA; sigmaS(expindex)= sigma_LS;
sigmaA(recindex) = sigma_HA; sigmaS(recindex) = sigma_HS;

rhoA_L=0.87; 
rhoA_H=0.87;
rhoS_L=0.01;
rhoS_H=0.01; 
rhoA(expindex)= rhoA_L; rhoA(recindex)= rhoA_H;
rhoS(expindex)= rhoS_L; rhoS(recindex)= rhoS_H;

a=zeros(T1,L); 
b=zeros(T1,L); 

Ashock = normrnd(0,1,T1,N);
Sshock = normrnd(0,1,T1,N);
Anoise = normrnd(0,1,T1,I,N);
Snoise = normrnd(0,1,T1,I,N);

for t=L+1:T1
      a(t,1)=sigmaA(t);b(t,1)=sigmaS(t);
   for l=2:L
      a(t,l)= a(t,l-1)/sigmaA(t-l+2)*sigmaA(t-l+1)*rhoA(t-l+2);
      b(t,l)= b(t,l-1)/sigmaS(t-l+2)*sigmaS(t-l+1)*rhoS(t-l+2);
   end
end

p_diamA = zeros(T1,N); p_diamS = zeros(T1,N);
for t=L+1:T1
    for n=1:N
        p_diamA(t,n)= a(t,:)*flipud(squeeze(Ashock(t-L:t-1,n)));
        p_diamS(t,n)= b(t,:)*flipud(squeeze(Sshock(t-L:t-1,n)));
    end
end

a=a(L+1:end,:); 
b=b(L+1:end,:);
p_diamA = p_diamA(L+1:end,:);
p_diamS = p_diamS(L+1:end,:);

T=size(a,1); 

options1 = optimset('LargeScale','Off','Display','Off','MaxIter',20,'TolFun',0.01,'TolX',0.01);
options2 = optimset('LargeScale','Off','Display','Off','MaxIter',20,'TolFun',0.01,'TolX',0.01);

kappa_low = 0.5;
kappa_high = 1.2;
r = (sqrt(5)-1)/2;
eps=0.001;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Dimensions and initial values
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

a_prior = zeros(T,L,I,N);b_prior = zeros(T,L,I,N);
a_post = zeros(T,L,I,N);b_post = zeros(T,L,I,N);
sigmaA_prior = zeros(T,I,N);sigmaS_prior = zeros(T,I,N);
sigmaA_post = zeros(T,I,N); sigmaS_post = zeros(T,I,N);
kappaA=zeros(T,I,N); kappaS=zeros(T,I,N); kappa = zeros(T,I,N);
mu_prior = 0.125*ones(T,I,N); 
mu_post = 0.125*ones(T,I,N);
c_actual=zeros(T,L,I,N); d_actual=zeros(T,L,I,N);f_actual=zeros(T,L,I,N);g_actual=zeros(T,L,I,N);

a_prior(1:L,:,:,:) = repmat(a(1:L,:),[1,1,I,N]); b_prior(1:L,:,:,:)  = repmat(b(1:L,:),[1,1,I,N]);
a_post(1:L,:,:,:)  = repmat(a(1:L,:),[1,1,I,N]); b_post(1:L,:,:,:)  = repmat(b(1:L,:),[1,1,I,N]);
sigmaA_prior(1:L+1,:,:) = repmat(sigmaA(1:L+1)',[1,I,N]); sigmaS_prior(1:L+1,:,:) = repmat(sigmaS(1:L+1)',[1,I,N]);
sigmaA_post(1:L,:,:) = repmat(sigmaA(1:L)',[1,I,N]); sigmaS_post(1:L,:,:) = repmat(sigmaS(1:L)',[1,I,N]);
pA=zeros(T,I,N);pS=zeros(T,I,N);
for i=1:I
    pA(1:L,i,:)= p_diamA(1:L,:); 
    pS(1:L,i,:)=p_diamS(1:L,:);
end

t=L+1; 
tic;
    a_prior(t,1,:,:) = sigmaA_prior(t,:,:);
    b_prior(t,1,:,:) = sigmaS_prior(t,:,:);
for l=2:L
    a_prior(t,l,:,:) = rhoA(t)*a_post(t-1,l-1,:,:);
    b_prior(t,l,:,:) = rhoS(t)*b_post(t-1,l-1,:,:);
end
    %Compute Optimal K 
    x1=kappa_low; x2=kappa_high;
    x3= r*x1 + (1-r)*x2;
    x4 = (1-r)*x1 + r*x2;
    
    [c_x3,d_x3,f_x3,g_x3,kappas1_x3,kappas2_x3] = alloc(x3,squeeze(a_prior(t,:,1,1))',squeeze(b_prior(t,:,1,1))',L,m,options1,options2);

    loss_x3= sum((squeeze(a_prior(t,:,1,1))'-c_x3).^2+(squeeze(b_prior(t,:,1,1))'-f_x3).^2+d_x3.^2+g_x3.^2)+phi*(kappas1_x3+kappas2_x3);

    [c_x4,d_x4,f_x4,g_x4,kappas1_x4,kappas2_x4] = alloc(x4,squeeze(a_prior(t,:,1,1))',squeeze(b_prior(t,:,1,1))',L,m,options1,options2);

    loss_x4= sum((squeeze(a_prior(t,:,1,1))'-c_x4).^2+(squeeze(b_prior(t,:,1,1))'-f_x4).^2+d_x4.^2+g_x4.^2)+phi*(kappas1_x4+kappas2_x4);
    
    g=zeros(size(g_x4));
    
    gap=1;
    while gap > eps
        if loss_x3 >= loss_x4
            x1=x3;
            x3=x4;
            loss_x3 = loss_x4;
            x4 = (1-r)*x1 + r*x2;
            [c,d,f,g, kappas1,kappas2] = alloc(x4,squeeze(a_prior(t,:,1,1))',squeeze(b_prior(t,:,1,1))',L,m,options1,options2);          
            loss_x4= sum((squeeze(a_prior(t,:,1,1))'-c).^2+(squeeze(b_prior(t,:,1,1))'-f).^2+d.^2+g.^2)+phi*(kappas1+kappas2);
        else
            x2 = x4;
            x4 = x3;
            loss_x4 = loss_x3;
            x3 = r*x1 + (1-r)*x2;
            [c,d,f,g,kappas1,kappas2] = alloc(x3,squeeze(a_prior(t,:,1,1))',squeeze(b_prior(t,:,1,1))',L,m,options1,options2);        
            loss_x3= sum((squeeze(a_prior(t,:,1,1))'-c).^2+(squeeze(b_prior(t,:,1,1))'-f).^2+d.^2+g.^2)+phi*(kappas1+kappas2);
        end
        gap=abs(x4-x3);
    end
    kappa_gold=(x3+x4)/2; 
    
    kappaA(t,:,:)=kappas1; kappaS(t,:,:)= kappas2; kappa(t,:,:)=kappa_gold;
    
    [c,d,f,g] = signalsolve(kappas1,kappas2,a(t,:)',b(t,:)',options1,L,m);
    c_actual(t,:,:,:)=repmat(c',[1,1,I,N]); d_actual(t,:,:,:)= repmat(d',[1,1,I,N]); 
    f_actual(t,:,:,:)= repmat(f',[1,1,I,N]); g_actual(t,:,:,:)=repmat(g',[1,1,I,N]);
    
    for i=1:I
        for n=1:N
            pA(t,i,n)=c_actual(t,:,i,n)*flipud(Ashock(t-L:t-1,n))+ d_actual(t,:,i,n)*flipud(squeeze(Anoise(t-L:t-1,i,n)));
            pS(t,i,n)=f_actual(t,:,i,n)*flipud(Sshock(t-L:t-1,n))+ g_actual(t,:,i,n)*flipud(squeeze(Snoise(t-L:t-1,i,n)));
            prHA=normpdf(pA(t,i,n),rhoA(t)*pA(t-1,i,n),sigma_HA);
            prLA=normpdf(pA(t,i,n),rhoA(t)*pA(t-1,i,n),sigma_LA);
            prHS=normpdf(pS(t,i,n),rhoS(t)*pS(t-1,i,n),sigma_HS);
            prLS=normpdf(pS(t,i,n),rhoS(t)*pS(t-1,i,n),sigma_LS);
            mu_post(t,i,n)= mu_prior(t,i,n) * prHA * prHS /(mu_prior(t,i,n) * prHA * prHS+ (1-mu_prior(t,i,n)) * prLA * prLS);
            sigmaA_post(t,i,n) = mu_post(t,i,n)*sigma_HA + (1-mu_post(t,i,n))*sigma_LA;
            sigmaS_post(t,i,n) = mu_post(t,i,n)*sigma_HS + (1-mu_post(t,i,n))*sigma_LS;
            
            a_post(t,1,i,n)= sigmaA_post(t,i,n);
            a_post(t,2:end,i,n) = a_prior(t,2:end,i,n);
            b_post(t,1,i,n)= sigmaS_post(t,i,n);
            b_post(t,2:end,i,n) = b_prior(t,2:end,i,n);
            
            mu_prior(t+1,i,n)=mu_post(t,i,n)*lambda1+(1-mu_post(t,i,n))*(1-lambda2);
            sigmaA_prior(t+1,i,n) = mu_prior(t+1,i,n)*sigma_HA + (1-mu_prior(t+1,i,n))*sigma_LA;
            sigmaS_prior(t+1,i,n) = mu_prior(t+1,i,n)*sigma_HS + (1-mu_prior(t+1,i,n))*sigma_LS;
        end
    end
    toc;
  
 for t = L+2:T-1 
     tic;
     a_prior(t,1,:,:) = sigmaA_prior(t,:,:);
     b_prior(t,1,:,:) = sigmaS_prior(t,:,:);
     for l=2:L
        a_prior(t,l,:,:) = rhoA(t)*a_post(t-1,l-1,:,:);
        b_prior(t,l,:,:) = rhoS(t)*b_post(t-1,l-1,:,:);
     end
     for i = 1:I
         for n = 1:N   
            x1= kappa_low;
            x2 = kappa_high;
            x3 =r*x1+(1-r)*x2;
            x4 =(1-r)*x1+r*x2;
            [c_x3,d_x3,kappas1_x3,kappas2_x3] = alloc(x3,squeeze(a_prior(t,:,i,n))',squeeze(b_prior(t,:,i,n))',L,m,options1,options2);
            f_x3=(1-2^(-2*kappas2_x3))*b_prior(t,:,1,1)';
            g_x3(1)=2^(-2*kappas2_x3)*sqrt(sum(b_prior(t,:,1,1).^2,2));
            loss_x3= sum((squeeze(a_prior(t,:,i,n))'-c_x3).^2+(squeeze(b_prior(t,:,i,n))'-f_x3).^2+d_x3.^2+g_x3.^2)+phi*(kappas1_x3+kappas2_x3);
            [c_x4,d_x4,kappas1_x4,kappas2_x4] = alloc(x4,squeeze(a_prior(t,:,i,n))',squeeze(b_prior(t,:,i,n))',L,m,options1,options2);
            f_x4=(1-2^(-2*kappas2_x4))*b_prior(t,:,1,1)';
            g_x4(1)=2^(-2*kappas2_x4)*sqrt(sum(b_prior(t,:,1,1).^2,2));
            loss_x4= sum((squeeze(a_prior(t,:,i,n))'-c_x4).^2+(squeeze(b_prior(t,:,i,n))'-f_x4).^2+d_x4.^2+g_x4.^2)+phi*(kappas1_x4+kappas2_x4);
    
            gap=1;
            while gap > eps
                if loss_x3 >= loss_x4
                    x1=x3;
                    x3=x4;
                    loss_x3 = loss_x4;
                    x4 = (1-r)*x1 + r*x2;
                    [c,d,kappas1,kappas2] = alloc(x4,squeeze(a_prior(t,:,1,1))',squeeze(b_prior(t,:,1,1))',L,m,options1,options2);
                    f=(1-2^(-2*kappas2))*b_prior(t,:,1,1)';
                    g(1)=2^(-2*kappas2)*sqrt(sum(b_prior(t,:,1,1).^2,2));
                    loss_x4= sum((squeeze(a_prior(t,:,1,1))'-c).^2+(squeeze(b_prior(t,:,1,1))'-f).^2+d.^2+g.^2)+phi*(kappas1+kappas2);
                else
                    x2 = x4;
                    x4 = x3;
                    loss_x4 = loss_x3;
                    x3 = r*x1 + (1-r)*x2;
                    [c,d,kappas1,kappas2] = alloc(x3,squeeze(a_prior(t,:,1,1))',squeeze(b_prior(t,:,1,1))',L,m,options1,options2);
                    f=(1-2^(-2*kappas2))*b_prior(t,:,1,1)';
                    g(1)=2^(-2*kappas2)*sqrt(sum(b_prior(t,:,1,1).^2,2));
                    loss_x3= sum((squeeze(a_prior(t,:,1,1))'-c).^2+(squeeze(b_prior(t,:,1,1))'-f).^2+d.^2+g.^2)+phi*(kappas1+kappas2);
                end
                gap=abs(x3-x4);
            end
            kappa(t,i,n)=(x3+x4)/2; 
    
            kappaA(t,i,n)=kappas1; kappaS(t,i,n)= kappas2; 
            
            [c,d] = signalsolve(kappas1,a(t,:)',options1,L,m);
            c_actual(t,:,i,n)=c'; d_actual(t,:,i,n)= d'; f_actual(t,:,i,n)= f'; g_actual(t,:,i,n)=g';
            
            pA(t,i,n)=c_actual(t,:,i,n)*flipud(Ashock(t-L:t-1,n))+ d_actual(t,:,i,n)*flipud(squeeze(Anoise(t-L:t-1,i,n)));
            pS(t,i,n)=f_actual(t,:,i,n)*flipud(Sshock(t-L:t-1,n))+ g_actual(t,:,i,n)*flipud(squeeze(Snoise(t-L:t-1,i,n)));
            
            prHA=normpdf(pA(t,i,n),rhoA_H*pA(t-1,i,n),sigma_HA);
            prLA=normpdf(pA(t,i,n),rhoA_L*pA(t-1,i,n),sigma_LA);
            prHS=normpdf(pS(t,i,n),rhoS_H*pS(t-1,i,n),sigma_HS);
            prLS=normpdf(pS(t,i,n),rhoS_L*pS(t-1,i,n),sigma_LS);
            mu_post(t,i,n)= mu_prior(t,i,n) * prHA * prHS /(mu_prior(t,i,n) * prHA * prHS+ (1-mu_prior(t,i,n)) * prLA * prLS);
            sigmaA_post(t,i,n) = mu_post(t,i,n)*sigma_HA + (1-mu_post(t,i,n))*sigma_LA;
            sigmaS_post(t,i,n) = mu_post(t,i,n)*sigma_HS + (1-mu_post(t,i,n))*sigma_LS;
            
            a_post(t,1,i,n)= sigmaA_post(t,i,n);
            a_post(t,2:end,i,n) = a_prior(t,2:end,i,n);
            b_post(t,1,i,n)= sigmaS_post(t,i,n);
            b_post(t,2:end,i,n) = b_prior(t,2:end,i,n);
            
            mu_prior(t+1,i,n)=mu_post(t,i,n)*lambda1+(1-mu_post(t,i,n))*(1-lambda2);
            sigmaA_prior(t+1,i,n) = mu_prior(t+1,i,n)*sigma_HA + (1-mu_prior(t+1,i,n))*sigma_LA;
            sigmaS_prior(t+1,i,n) = mu_prior(t+1,i,n)*sigma_HS + (1-mu_prior(t+1,i,n))*sigma_LS;
            
         end
        
     end
     t
     toc;
    
 end
    
    ave_i_mupost=zeros(T-1,N);
    ave_i_muprior=zeros(T-1,N);
    for t=1:T-1
        for n=1:N
            ave_i_mupost(t,n) = mean(mu_post(t,:,n),2);
            ave_i_muprior(t,n) = mean(mu_prior(t,:,n),2);
        end
    end
    
   ave_mupost=zeros(T-1,1);
   ave_muprior=zeros(T-1,1);
   for t=1:T-1
       ave_mupost(t,1)=mean(ave_i_mupost(t,:),2);
       ave_muprior(t,1)=mean(ave_i_muprior(t,:),2);
   end

      ave_i_ka =zeros(T-1,N);
      ave_i_ks =zeros(T-1,N);
    for t=1:T-1
        for n=1:N
            ave_i_ka(t,n) = mean(kappaA(t,:,n),2);
            ave_i_ks(t,n) = mean(kappaS(t,:,n),2);
        end
    end
   ave_i_k = ave_i_ka+ave_i_ks;
    
   ave_ka=zeros(T-1,1);
   ave_ks=zeros(T-1,1);
   for t=1:T-1
       ave_ka(t)=mean(ave_i_ka(t,:),2);
       ave_ks(t)=mean(ave_i_ks(t,:),2);
   end 
   ave_k = ave_ka+ave_ks;
  
  ave_i_pa =zeros(T-1,N);
  ave_i_ps =zeros(T-1,N);
    for t=1:T-1
        for n=1:N
            ave_i_pa(t,n) = mean(pA(t,:,n),2);
            ave_i_ps(t,n) = mean(pS(t,:,n),2);
        end
    end
   ave_i_p = ave_i_pa+ave_i_ps;
    
   ave_pa=zeros(T-1,1);
   ave_ps=zeros(T-1,1);
   ave_pdiamA=zeros(T-1,1);
   ave_pdiamS=zeros(T-1,1);
   
   for t=1:T-1
       ave_pa(t)=mean(ave_i_pa(t,:),2);
       ave_ps(t)=mean(ave_i_ps(t,:),2);
       ave_pdiamA(t)=mean(p_diamA(t,:),2);
       ave_pdiamS(t)=mean(p_diamS(t,:),2);
   end 
   ave_p = ave_pa+ave_ps;
   ave_pdiam = ave_pdiamA+ave_pdiamS;
   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Figures
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   
   timeplot = 1:((T1-2*L)-1);
   timeplot=timeplot';
   recindexplot=recindex - 2*L;
   expindexplot=expindex - 2*L;
   expindexplot=expindexplot(2*L+1:end);
   
   ave_mupost = ave_mupost(L+1:end);
   ave_muprior= ave_muprior(L+1:end);
   ave_ka = ave_ka(L+1:end);
   ave_ks = ave_ks(L+1:end);
   ave_k = ave_k(L+1:end);
   ave_pa = ave_pa(L+1:end);
   ave_ps = ave_ps(L+1:end);
   ave_p = ave_p(L+1:end);
   ave_pdiamA =ave_pdiamA(L+1:end);
   ave_pdiamS =ave_pdiamS(L+1:end);
   ave_pdiam =ave_pdiam(L+1:end);
  
figure()

plotk(recindexplot)= max(ave_k)+0.2;
plotk(expindexplot)= min(ave_k)-0.2;
plotkas(recindexplot)= max(ave_ks)+0.2;
plotkas(expindexplot)= min(ave_ka)-0.2;

subplot(121) 

plot11=plot(timeplot,ave_k);
title('Optimal Information Capacity');
xlabel('time');
ylabel('Attention');
legend('Total Attention');
set(plot11,'Marker','.')
ylim([min(plotk),max(plotk)]);
patch('YData',plotk(1:end-1),'XData',timeplot,'Facealpha',0.5,'EdgeColor',[0.831372549019608 0.815686274509804 0.784313725490196],'FaceColor',[0.831372549019608 0.815686274509804 0.784313725490196]);

subplot(122) 
plot12=plot(timeplot,ave_ka,timeplot,ave_ks);
title('Optimal Attention Allocation');
xlabel('time');
ylabel('Attention');
legend('Attention to Aggregate Conditions','Attention to Idiosyncratic Conditions');
set(plot12(1),'Marker','.');
set(plot12(2),'Marker','.','Color',[1,0,0]);
ylim([min(plotkas),max(plotkas)]);
patch('YData',plotkas(1:end-1),'XData',timeplot,'Facealpha',0.5,'EdgeColor',[0.831372549019608 0.815686274509804 0.784313725490196],'FaceColor',[0.831372549019608 0.815686274509804 0.784313725490196]);
   
figure() 

plotmu(recindexplot)= 1;
plotmu(expindexplot)= 0;

plot2=plot(timeplot,ave_mupost);
title('Posterior Probability (sigma = sigma_H)');
xlabel('Time');
ylabel('Probability');
ylim([0 1]);
patch('YData',plotmu(1:end-1),'XData',timeplot,'Facealpha',0.5,'FaceColor',[0.831372549019608 0.815686274509804 0.784313725490196],'EdgeColor',[0.831372549019608 0.815686274509804 0.784313725490196]);

figure() 

plot3=plot(timeplot,ave_muprior,timeplot,ave_mupost);
title('Prior and Posterior Probability');
xlabel('Time');
ylabel('Probability');
legend('Prior','Posterior');
ylim([0 1]);
patch('YData',plotmu(1:end-1),'XData',timeplot,'Facealpha',0.5,'FaceColor',[0.831372549019608 0.815686274509804 0.784313725490196],'EdgeColor',[0.831372549019608 0.815686274509804 0.784313725490196]);
   
figure()

plotp(recindexplot)= max(max(ave_pdiam),max(ave_p))+1;
plotp(expindexplot)= min(min(ave_pdiam),min(ave_p))-1;
plotpa(recindexplot)= max(max(ave_pdiamA),max(ave_pa))+1;
plotpa(expindexplot)= min(min(ave_pdiamA),min(ave_pa))-1;
plotps(recindexplot)= max(max(ave_pdiamS),max(ave_ps))+1;
plotps(expindexplot)= min(min(ave_pdiamS),min(ave_ps))-1;

subplot(131) 

plot41=plot(timeplot,ave_pdiam,timeplot,ave_p);
title('Price: Optimal vs Actual');
xlabel('Time');
ylabel('Price');
legend('Optimal','Actual');
set(plot41(1),'LineStyle','--')
set(plot41(2),'Marker','.')
ylim([min(plotp) max(plotp)]);
patch('YData',plotp(1:end-1),'XData',timeplot,'Facealpha',0.5,'EdgeColor',[0.831372549019608 0.815686274509804 0.784313725490196],'FaceColor',[0.831372549019608 0.815686274509804 0.784313725490196]);

subplot(132) 

plot42=plot(timeplot,ave_pdiamA,timeplot,ave_pa);
title('Price(aggregate): Optimal vs Actual');
xlabel('Time');
ylabel('Price');
legend('Optimal','Actual');
set(plot42(1),'LineStyle','--')
set(plot42(2),'Marker','.')
ylim([min(plotpa) max(plotpa)]);
patch('YData',plotpa(1:end-1),'XData',timeplot,'Facealpha',0.5,'EdgeColor',[0.831372549019608 0.815686274509804 0.784313725490196],'FaceColor',[0.831372549019608 0.815686274509804 0.784313725490196]);

subplot(133) 
plot43=plot(timeplot,ave_pdiamS,timeplot,ave_ps);
title('Price(idio): Optimal vs Actual');
xlabel('Time');
ylabel('Price');
legend('Optimal','Actual');
set(plot43(1),'LineStyle','--')
set(plot43(2),'Marker','.')
ylim([min(plotps) max(plotps)]);
patch('YData',plotps(1:end-1),'XData',timeplot,'Facealpha',0.5,'EdgeColor',[0.831372549019608 0.815686274509804 0.784313725490196],'FaceColor',[0.831372549019608 0.815686274509804 0.784313725490196]);


save('simulresult.mat')

